close all; clear all;

dpar = struct();
dpar.inRate_Hz = 2; % frequency range -1..1

% ********************************************
% root-raised cosine example
% ********************************************
alpha = 0.15;
f = linspace(0, 1, 100000);
c = abs(f / 0.5);
c = (c-1)/(alpha); % -1..1 in the transition region
c=min(c, 1);
c=max(c, -1);
RRC_H = sqrt(1/2+cos(pi/2*(c+1))/2);

f = [f, 1e19];
RRC_H = [RRC_H, RRC_H(end)];

% set RRC target to filter design algorithm
dpar.nominalFreq_Hz = f;
dpar.nominalGain_dB = 20*log10(RRC_H + 1e-19);

dpar.mStages = 64;
EVM = -43;

mode = 'conventional';
%mode = 'equalized';
switch mode
  case 'conventional'
    outfilename = 'RRC.dat';
  case 'equalized'
    tmp = load('interpolatorFrequencyResponse.mat');
    dpar.equalizeFreq_Hz = tmp.fb;
    dpar.equalizeComplexGain = tmp.fr;    
    outfilename = 'RRC_equalized.dat';
 otherwise assert(false);
end

% dpar.convergedIterations = 0; % use remaining degrees of freedom for LMS optimization
dpar.convergedIterations = 10; % force equiripple

design = YAFIR(dpar);

halfBW = 0.5 * (1+alpha);

design = placePassband(...
    design, ...
    'f_Hz', [0, halfBW], ...
    'EVM_dB', EVM);

design = placeStopband(...
    design, ...
    'f_Hz', [halfBW * 1.03, halfBW * 1.1, 1, 9e9], ...
                'g_dB', [-20, -40, -80, -80]);

[h, status] = run(design); 
if strcmp(status, 'converged')
    disp('saving');
    save(outfilename, 'h', '-ascii');
end
disp(status);    
